# Test Coverage Report

Generated: Thu 2012-03-01 14:22 CST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 530 | 296 | 79 | 65.6%
permission.admin | 69 | 0 | 7 | 0.0%
permission.backends.authenticate_backend | 22 | 11 | 3 | 57.9%
permission.backends.permission_backend | 22 | 15 | 2 | 75.0%
permission.backends.role_backend | 61 | 35 | 4 | 61.4%
permission.decorators.class_decorators | 19 | 14 | 5 | 100.0%
permission.decorators.function_decorators | 28 | 18 | 9 | 94.7%
permission.decorators.method_decorators | 27 | 20 | 7 | 100.0%
permission.decorators.utils | 94 | 69 | 12 | 84.1%
permission.exceptions | 14 | 6 | 1 | 46.2%
permission.handlers.base | 33 | 19 | 3 | 63.3%
permission.models | 96 | 76 | 10 | 88.4%
permission.utils | 30 | 5 | 11 | 26.3%
permission.validation | 15 | 8 | 5 | 80.0%

Excluded packages and modules